@@ -15,7 +15,8 @@
 
 class QWidget;
 
-namespace Akregator {
+namespace Akregator
+{
 class AKREGATORINTERFACES_EXPORT Command : public QObject
 {
     Q_OBJECT
