@@ -10,17 +10,18 @@
 
 #include <QObject>
 class QString;
-class QStringList;
+#include <QStringList>
 class QDateTime;
 
-namespace Akregator {
-namespace Backend {
+namespace Akregator
+{
+namespace Backend
+{
 class Storage;
 
-class FeedStorage : public QObject //krazy:exclude=qobject
+class FeedStorage : public QObject // krazy:exclude=qobject
 {
 public:
-
     virtual int unread() const = 0;
     virtual void setUnread(int unread) = 0;
     virtual int totalCount() const = 0;
