@@ -8,8 +8,10 @@
 
 #include "plugin.h"
 
-namespace Akregator {
-Plugin::Plugin(QObject *parent, const QVariantList &) : QObject(parent)
+namespace Akregator
+{
+Plugin::Plugin(QObject *parent, const QVariantList &)
+    : QObject(parent)
 {
 }
 
@@ -17,8 +19,7 @@ Plugin::~Plugin()
 {
 }
 
-void
-Plugin::addPluginProperty(const QString &key, const QString &value)
+void Plugin::addPluginProperty(const QString &key, const QString &value)
 {
     m_properties[key.toLower()] = value;
 }
@@ -28,8 +29,7 @@ void Plugin::initialize()
     doInitialize();
 }
 
-QString
-Plugin::pluginProperty(const QString &key) const
+QString Plugin::pluginProperty(const QString &key) const
 {
     if (m_properties.find(key.toLower()) == m_properties.end()) {
         return QStringLiteral("false");
@@ -38,8 +38,7 @@ Plugin::pluginProperty(const QString &key) const
     return m_properties[key.toLower()];
 }
 
-bool
-Plugin::hasPluginProperty(const QString &key) const
+bool Plugin::hasPluginProperty(const QString &key) const
 {
     return m_properties.find(key.toLower()) != m_properties.end();
 }
