@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef AKREGATORUSERFEEDBACKPROVIDER_H
 #define AKREGATORUSERFEEDBACKPROVIDER_H
 
-#include <KUserFeedback/Provider>
 #include "akregatorinterfaces_export.h"
-namespace Akregator {
+#include <KUserFeedback/Provider>
+namespace Akregator
+{
 class AKREGATORINTERFACES_EXPORT AkregatorUserFeedbackProvider : public KUserFeedback::Provider
 {
     Q_OBJECT
