@@ -1,23 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "crashwidget.h"
-#include <QVBoxLayout>
 #include <KLocalizedString>
-#include <QPushButton>
 #include <QLabel>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace Akregator;
 
 CrashWidget::CrashWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
 
-    auto *labelLayout = new QHBoxLayout;
+    auto labelLayout = new QHBoxLayout;
     QLabel *label = new QLabel(i18n("Akregator did not close correctly. Would you like to restore the previous session?"), this);
     label->setObjectName(QStringLiteral("restoresessionlabel"));
     label->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -30,7 +30,7 @@ CrashWidget::CrashWidget(QWidget *parent)
     labelLayout->addWidget(label);
     labelLayout->addStretch(0);
 
-    auto *buttonLayout = new QHBoxLayout;
+    auto buttonLayout = new QHBoxLayout;
     vbox->addLayout(buttonLayout);
     buttonLayout->addStretch(0);
 
