@@ -7,24 +7,24 @@
 */
 
 #include "feedlist.h"
-#include "storage.h"
 #include "article.h"
 #include "feed.h"
 #include "folder.h"
+#include "storage.h"
 #include "treenode.h"
 #include "treenodevisitor.h"
 
+#include "akregator_debug.h"
 #include "kernel.h"
 #include "subscriptionlistjobs.h"
-#include <memory>
-#include "akregator_debug.h"
 #include <KLocalizedString>
+#include <memory>
 
-#include <qdom.h>
-#include <QHash>
-#include <QSet>
 #include <QElapsedTimer>
+#include <QHash>
 #include <QRandomGenerator>
+#include <QSet>
+#include <qdom.h>
 
 using namespace Akregator;
 class Q_DECL_HIDDEN FeedList::Private
@@ -40,14 +40,15 @@ public:
     QHash<int, TreeNode *> idMap;
     AddNodeVisitor *addNodeVisitor;
     RemoveNodeVisitor *removeNodeVisitor;
-    QHash<QString, QList<Feed *> > urlMap;
+    QHash<QString, QList<Feed *>> urlMap;
     mutable int unreadCache;
 };
 
 class FeedList::AddNodeVisitor : public TreeNodeVisitor
 {
 public:
-    AddNodeVisitor(FeedList *list) : m_list(list)
+    AddNodeVisitor(FeedList *list)
+        : m_list(list)
     {
     }
 
@@ -56,16 +57,11 @@ public:
         m_list->d->idMap.insert(node->id(), node);
         m_list->d->flatList.append(node);
         m_list->d->urlMap[node->xmlUrl()].append(node);
-        connect(node, &Feed::fetchStarted,
-                m_list, &FeedList::fetchStarted);
-        connect(node, &Feed::fetched,
-                m_list, &FeedList::fetched);
-        connect(node, &Feed::fetchAborted,
-                m_list, &FeedList::fetchAborted);
-        connect(node, &Feed::fetchError,
-                m_list, &FeedList::fetchError);
-        connect(node, &Feed::fetchDiscovery,
-                m_list, &FeedList::fetchDiscovery);
+        connect(node, &Feed::fetchStarted, m_list, &FeedList::fetchStarted);
+        connect(node, &Feed::fetched, m_list, &FeedList::fetched);
+        connect(node, &Feed::fetchAborted, m_list, &FeedList::fetchAborted);
+        connect(node, &Feed::fetchError, m_list, &FeedList::fetchError);
+        connect(node, &Feed::fetchDiscovery, m_list, &FeedList::fetchDiscovery);
 
         visitTreeNode(node);
         return true;
@@ -115,7 +111,8 @@ private:
 class FeedList::RemoveNodeVisitor : public TreeNodeVisitor
 {
 public:
-    RemoveNodeVisitor(FeedList *list) : m_list(list)
+    RemoveNodeVisitor(FeedList *list)
+        : m_list(list)
     {
     }
 
@@ -176,17 +173,17 @@ QVector<int> FeedList::feedIds() const
     return ids;
 }
 
-QVector<const Feed *> FeedList::feeds() const
+QVector<const Akregator::Feed *> FeedList::feeds() const
 {
-    QVector<const Feed *> constList;
+    QVector<const Akregator::Feed *> constList;
     const auto rootNodeFeeds = d->rootNode->feeds();
-    for (const Feed *const i : rootNodeFeeds) {
+    for (const Akregator::Feed *const i : rootNodeFeeds) {
         constList.append(i);
     }
     return constList;
 }
 
-QVector<Feed *> FeedList::feeds()
+QVector<Akregator::Feed *> FeedList::feeds()
 {
     return d->rootNode->feeds();
 }
@@ -221,7 +218,7 @@ void FeedList::parseChildNodes(QDomNode &node, Folder *parent)
     QDomElement e = node.toElement(); // try to convert the node to an element.
 
     if (!e.isNull()) {
-        //QString title = e.hasAttribute("text") ? e.attribute("text") : e.attribute("title");
+        // QString title = e.hasAttribute("text") ? e.attribute("text") : e.attribute("title");
 
         if (e.hasAttribute(QStringLiteral("xmlUrl")) || e.hasAttribute(QStringLiteral("xmlurl")) || e.hasAttribute(QStringLiteral("xmlURL"))) {
             Feed *feed = Feed::fromOPML(e, d->storage);
@@ -301,7 +298,7 @@ FeedList::~FeedList()
     delete d;
 }
 
-const Feed *FeedList::findByURL(const QString &feedURL) const
+const Akregator::Feed *FeedList::findByURL(const QString &feedURL) const
 {
     if (!d->urlMap.contains(feedURL)) {
         return nullptr;
@@ -310,18 +307,18 @@ const Feed *FeedList::findByURL(const QString &feedURL) const
     return !v.isEmpty() ? v.front() : nullptr;
 }
 
-Feed *FeedList::findByURL(const QString &feedURL)
+Akregator::Feed *FeedList::findByURL(const QString &feedURL)
 {
     if (!d->urlMap.contains(feedURL)) {
         return nullptr;
     }
-    const QList<Feed *> &v = d->urlMap[feedURL];
+    const QList<Akregator::Feed *> &v = d->urlMap[feedURL];
     return !v.isEmpty() ? v.front() : nullptr;
 }
 
 const Article FeedList::findArticle(const QString &feedURL, const QString &guid) const
 {
-    const Feed *feed = findByURL(feedURL);
+    const Akregator::Feed *feed = findByURL(feedURL);
     return feed ? feed->findArticle(guid) : Article();
 }
 
@@ -493,7 +490,8 @@ KJob *FeedList::createMarkAsReadJob()
     return d->rootNode ? d->rootNode->createMarkAsReadJob() : nullptr;
 }
 
-FeedListManagementImpl::FeedListManagementImpl(const QSharedPointer<FeedList> &list) : m_feedList(list)
+FeedListManagementImpl::FeedListManagementImpl(const QSharedPointer<FeedList> &list)
+    : m_feedList(list)
 {
 }
 
@@ -533,11 +531,7 @@ QStringList FeedListManagementImpl::feeds(const QString &catId) const
         return QStringList();
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const uint lastcatid = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
-#else
     const uint lastcatid = catId.split(QLatin1Char('/'), Qt::SkipEmptyParts).last().toUInt();
-#endif
 
     QSet<QString> urls;
     const auto feeds = m_feedList->feeds();
@@ -556,11 +550,7 @@ void FeedListManagementImpl::addFeed(const QString &url, const QString &catId)
     }
 
     qCDebug(AKREGATOR_LOG) << "Name:" << url.left(20) << "Cat:" << catId;
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const uint folder_id = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
-#else
     const uint folder_id = catId.split(QLatin1Char('/'), Qt::SkipEmptyParts).last().toUInt();
-#endif
 
     // Get the folder
     Folder *m_folder = nullptr;
@@ -590,18 +580,14 @@ void FeedListManagementImpl::removeFeed(const QString &url, const QString &catId
 {
     qCDebug(AKREGATOR_LOG) << "Name:" << url.left(20) << "Cat:" << catId;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    uint lastcatid = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
-#else
     uint lastcatid = catId.split(QLatin1Char('/'), Qt::SkipEmptyParts).last().toUInt();
-#endif
 
     const auto feeds = m_feedList->feeds();
     for (const Feed *const i : feeds) {
         if (lastcatid == i->parent()->id()) {
             if (i->xmlUrl().compare(url) == 0) {
                 qCDebug(AKREGATOR_LOG) << "id:" << i->id();
-                auto *job = new DeleteSubscriptionJob;
+                auto job = new DeleteSubscriptionJob;
                 job->setSubscriptionId(i->id());
                 job->start();
             }
@@ -617,11 +603,7 @@ QString FeedListManagementImpl::getCategoryName(const QString &catId) const
         return catname;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList list = catId.split(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
     const QStringList list = catId.split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
     for (int i = 0; i < list.size(); ++i) {
         int index = list.at(i).toInt();
         catname += m_feedList->findByID(index)->title() + QLatin1Char('/');
