@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef DEFAULTCOMBINEDVIEWFORMATTER_H
 #define DEFAULTCOMBINEDVIEWFORMATTER_H
 
-#include "articleformatter.h"
 #include "akregator_export.h"
+#include "articleformatter.h"
 class QPaintDevice;
-namespace Akregator {
+namespace Akregator
+{
 class GrantleeViewFormatter;
 class AKREGATOR_EXPORT DefaultCombinedViewFormatter : public ArticleFormatter
 {
