@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef DEFAULTNORMALVIEWFORMATTER_H
 #define DEFAULTNORMALVIEWFORMATTER_H
 
-#include "articleformatter.h"
 #include "akregator_export.h"
+#include "articleformatter.h"
 class QPaintDevice;
-namespace Akregator {
+namespace Akregator
+{
 class GrantleeViewFormatter;
 class AKREGATOR_EXPORT DefaultNormalViewFormatter : public ArticleFormatter
 {
 public:
-
     explicit DefaultNormalViewFormatter(const QString &grantleeDirectory, QPaintDevice *device = nullptr);
     ~DefaultNormalViewFormatter() override;
 
