@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,10 +13,12 @@
 #include "akregator_export.h"
 class QTemporaryFile;
 class KJob;
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 class AttachmentTemporaryFilesDirs;
 }
-namespace Akregator {
+namespace Akregator
+{
 class AKREGATOR_EXPORT DownloadArticleJob : public QObject
 {
     Q_OBJECT
