@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,8 @@
 #include <QUrl>
 
 #include "akregator_export.h"
-namespace Akregator {
+namespace Akregator
+{
 class AKREGATOR_EXPORT DownloadFeedIconJob : public QObject
 {
     Q_OBJECT
@@ -29,6 +30,7 @@ public:
 
 Q_SIGNALS:
     void result(const QString &fileName);
+
 private:
     QUrl mFeedIconUrl;
     bool mDownloadFavicon = true;
